|Continuous integration| |Test coverage| |All Contributors|

BioSimulations-BiGG
===================

BioSimulations-BiGG provides a command-line application for publishing
the `BiGG model repository <http://bigg.ucsd.edu/>`__ of flux balance
models to the `BioSimulations <https://biosimulations.org>`__ repository
for simulation projects.

This command-line program is run weekly by the GitHub action in this
repository.

Installation
------------

Requirements
~~~~~~~~~~~~

-  Python >= 3.7
-  pip

Install latest revision from GitHub
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

::

   pip install git+https://github.com/biosimulations/biosimulations-bigg.git#biosimulations-bigg

API documentation
-----------------

API documentation is available
`here <https://docs.biosimulations.org/repositories/bigg>`__.

License
-------

This package is released under the `MIT license <LICENSE>`__. BiGG is
licensed under the `BiGG License <http://bigg.ucsd.edu/license>`__.

Development team
----------------

This package was developed by the `Karr Lab <https://www.karrlab.org>`__
at the Icahn School of Medicine at Mount Sinai in New York and the
`Center for Reproducible Biomedical
Modeling <http://reproduciblebiomodels.org>`__. BiGG was developed by
the `Systems Biology Research
Group <https://systemsbiology.ucsd.edu/>`__ at the University of
California, San Diego with assistance from the contributors listed
`here <CONTRIBUTORS.md>`__.

Contributing to BioSimulations-BiGG
-----------------------------------

We enthusiastically welcome contributions to BioSimulations-BiGG! Please
see the `guide to contributing <CONTRIBUTING.md>`__ and the `developer's
code of conduct <CODE_OF_CONDUCT.md>`__.

Acknowledgements
----------------

This work was supported by National Institutes of Health award
P41EB023912.

Questions and comments
----------------------

Please contact the `BioSimulations
Team <mailto:info@biosimulations.org>`__ with any questions or comments
about this package. Please contact the `BiGG
Team <https://github.com/SBRG/bigg_models/issues>`__ with any questions
or comments about BiGG.

.. |Continuous integration| image:: https://github.com/biosimulations/biosimulations-bigg/actions/workflows/ci.yml/badge.svg
   :target: https://github.com/biosimulations/biosimulations-bigg/actions/workflows/ci.yml
.. |Test coverage| image:: https://codecov.io/gh/biosimulations/biosimulations-bigg/branch/dev/graph/badge.svg
   :target: https://codecov.io/gh/biosimulations/biosimulations-bigg
.. |All Contributors| image:: https://img.shields.io/github/all-contributors/biosimulations/biosimulations-bigg/HEAD
   :target: #contributors-
